@@ -30,10 +30,9 @@ void ffPrintLoadavg(FFLoadavgOptions* options)
         {
             FFCPUResult cpu = {
                 .temperature = FF_CPU_TEMP_UNSET,
-                .frequencyMin = 0.0/0.0,
-                .frequencyMax = 0.0/0.0,
-                .frequencyBase = 0.0/0.0,
-                .frequencyBiosLimit = 0.0/0.0,
+                .frequencyMax = 0,
+                .frequencyBase = 0,
+                .frequencyBiosLimit = 0,
                 .name = ffStrbufCreate(),
                 .vendor = ffStrbufCreate(),
             };
@@ -50,9 +49,10 @@ void ffPrintLoadavg(FFLoadavgOptions* options)
                 else
                 {
                     ffStrbufClear(&buffer);
-                    FF_PARSE_FORMAT_STRING_CHECKED(&buffer, &options->moduleArgs.key, 2, ((FFformatarg[]){
+                    FF_PARSE_FORMAT_STRING_CHECKED(&buffer, &options->moduleArgs.key, 3, ((FFformatarg[]){
                         {FF_FORMAT_ARG_TYPE_UINT, &index, "index"},
                         {FF_FORMAT_ARG_TYPE_UINT, &duration, "duration"},
+                        {FF_FORMAT_ARG_TYPE_STRBUF, &options->moduleArgs.keyIcon, "icon"},
                     }));
                 }
 
@@ -203,7 +203,7 @@ void ffInitLoadavgOptions(FFLoadavgOptions* options)
         ffPrintLoadavgHelpFormat,
         ffGenerateLoadavgJsonConfig
     );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    ffOptionInitModuleArg(&options->moduleArgs, "");
 
     options->percent = (FFColorRangeConfig) { 50, 80 };
     options->ndigits = 2;
